@@ -1,4 +1,4 @@
-simData1s <- function(n=10, mean=500, kappa=0.5, phi=1, f=50,rounding=TRUE){
+simData1s <- function(n=10, mean=500, kappa=0.5, phi=1, f=50, rounding=TRUE, seed = NULL){
   # error checking
   if (n%%1!=0) {stop("sample size is not an integer")}
   if (kappa<0) {stop("overdispersion parameter is not positive")}
@@ -6,6 +6,8 @@ simData1s <- function(n=10, mean=500, kappa=0.5, phi=1, f=50,rounding=TRUE){
   if (sum(f%%1!=0)>0) {stop("correction factor is not integer(s)")}
   if (!is.logical(rounding)) {stop("rounding argument is not a logical")}
   if (length(f)>1 && length(f)!=n) {stop("the length of correction factors and sample size do not match")}
+  # random seed
+  if (!is.null(seed)) {set.seed(seed)}
    # sample true egg counts
    trueMean <- rgamma(n,shape=kappa, rate=kappa/mean)
    infected <- sample(c(FALSE,TRUE),size=n, replace=TRUE,prob=c(1-phi,phi))
@@ -17,11 +19,12 @@ simData1s <- function(n=10, mean=500, kappa=0.5, phi=1, f=50,rounding=TRUE){
    } else {
      fec <- rpois(n,lambda=trueEPG/f)}
    # fec <- rbinom(n,trueEPG,1/f)
-   data <- cbind(obs=fec*f, master=fec, true=trueEPG)
+   data <- data.frame(obs=fec*f, master=fec, true=trueEPG)
    return(data)
 }
 
-simData2s <- function(n=10, preMean=500, delta=0.1, kappa=0.5,phiPre=1,phiPost=phiPre, f=50, paired=TRUE,rounding=TRUE){
+simData2s <- function(n=10, preMean=500, delta=0.1, kappa=0.5, deltaShape = NULL,
+                      phiPre=1, phiPost=phiPre, f=50, paired=TRUE, rounding=TRUE, seed = NULL){
   # error checking
   if (n%%1!=0) {stop("sample size is not an integer")}
   if (kappa<0) {stop("overdispersion parameter is not positive")}
@@ -31,6 +34,8 @@ simData2s <- function(n=10, preMean=500, delta=0.1, kappa=0.5,phiPre=1,phiPost=p
   if (!is.logical(paired)) {stop("paired is not a logical")}
   if (!is.logical(rounding)) {stop("rounding argument is not a logical")}
   if (length(f)>1 && length(f)!=n) {stop("the length of correction factors and sample size do not match")}
+  # random seed
+  if (!is.null(seed)) {set.seed(seed)}
   if(paired){
 	# sample true egg counts before treatment
 	truePreMean <- rgamma(n,shape=kappa, rate=kappa/preMean)
@@ -46,7 +51,12 @@ simData2s <- function(n=10, preMean=500, delta=0.1, kappa=0.5,phiPre=1,phiPost=p
 	infectedA <- infected
 	infectedA[infected] <- sample(c(FALSE,TRUE),size=sum(infected), replace=TRUE,prob=c(1-phiPost/phiPre,phiPost/phiPre))
 
-	truePostMean <- truePreMean*delta
+	if (is.null(deltaShape)){
+	  deltas <- delta
+	} else {
+	  deltas <- rgamma(n, shape = deltaShape, rate = deltaShape/delta)
+	}
+	truePostMean <- truePreMean*deltas
 	truePostMean[!infectedA] <- 0
 	truePostEPG <- rpois(n,truePostMean)
 	# take a subsample and count eggs y, such that epg = f*y
@@ -54,13 +64,20 @@ simData2s <- function(n=10, preMean=500, delta=0.1, kappa=0.5,phiPre=1,phiPost=p
 	postFEC <- rpois(n,lambda=round(truePostEPG/f))
 	} else {postFEC <- rpois(n,lambda=truePostEPG/f)}
 	#postFEC <- rbinom(n,truePostEPG,1/f)	
-	data <- cbind(obsPre =fec*f, masterPre=fec, truePre=truePreEPG, obsPost=postFEC*f, masterPost=postFEC, truePost=truePostEPG)
+	data <- data.frame(obsPre =fec*f, masterPre=fec, truePre=truePreEPG, obsPost=postFEC*f, masterPost=postFEC, truePost=truePostEPG)
 
   } else {
+    
+    if (is.null(deltaShape)){
+      deltas <- delta
+    } else {
+      deltas <- rgamma(n, shape = deltaShape, rate = deltaShape/delta)
+    }
+    
 	dataPre <- simData1s(n=n, mean=preMean, kappa=kappa, phi=phiPre,rounding=rounding)
-	dataPost <- simData1s(n=n, mean=preMean*delta, kappa=kappa, phi=phiPost,rounding=rounding)
+	dataPost <- simData1s(n=n, mean=preMean*deltas, kappa=kappa, phi=phiPost,rounding=rounding)
 
-	data <- cbind(dataPre,dataPost)
+	data <- data.frame(dataPre,dataPost)
     colnames(data) <- paste(colnames(data),rep(c("pre","post"),each=3),sep=".")
 	  
   }
